hstrat.test.test\_helpers.test\_attach\_attrs
=============================================

.. automodule:: hstrat.test.test_helpers.test_attach_attrs

   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      TestAttachAttrs
   
   

   
   
   



